package fwpUtil;

import java.awt.RenderingHints;

/**
 * Title: Get rendering hints for maximum quality or maximum speed.</p>
 *
 * Description: GetHints packages all of the maximum quality and maximum speed
 * rendering hints into to methods.
 *  methods.
 * </p>
 * Copyright: Copyright (c) 2011
 * </p>
  * @author Fred Pospeschil - This file is placed in the public domain
 * and can be used and adapted without restrictions.  The user of the code is
 * totally responsible for insuring its suitability in the intended application.
 * <p>
 * @version 1.0
 */
public final class GetHints
  {
  /**
   * Creates a rendering "hints" which has all hint values set for maximum speed.
   *
   * @return A rendering hint which has all of the hint values set for
   * maximum speed.  To use:
   * <p>
   * <code>RenderingHints hints = GetHints.getSpeedRenderingHints();</code>
   * <p>
   * Then load the hints with <code>g2D.setRenderingHints(hints);</code>
   *<code>System.out.println("QualityHints="+qualityHints.toString());</code>
   * <p>
   * Where <code>g2D</code> is a Graphics2D object.
   */
  public static RenderingHints getSpeedRenderingHints()
    {
    RenderingHints hints = new RenderingHints(RenderingHints.KEY_ANTIALIASING,
                                              RenderingHints.VALUE_ANTIALIAS_OFF);
    hints.add(new RenderingHints(RenderingHints.KEY_ALPHA_INTERPOLATION,
                                 RenderingHints.VALUE_ALPHA_INTERPOLATION_SPEED));
    hints.add(new RenderingHints(RenderingHints.KEY_RENDERING,
                                 RenderingHints.VALUE_RENDER_SPEED));
    hints.add(new RenderingHints(RenderingHints.KEY_DITHERING,
                                 RenderingHints.VALUE_DITHER_DISABLE));
    hints.add(new RenderingHints(RenderingHints.KEY_COLOR_RENDERING,
                                 RenderingHints.VALUE_RENDER_SPEED));
    hints.add(new RenderingHints(RenderingHints.KEY_FRACTIONALMETRICS,
                                 RenderingHints.VALUE_FRACTIONALMETRICS_OFF));
    hints.add(new RenderingHints(RenderingHints.KEY_TEXT_ANTIALIASING,
                                 RenderingHints.VALUE_TEXT_ANTIALIAS_OFF));
    hints.add(new RenderingHints(RenderingHints.KEY_INTERPOLATION,
                                 RenderingHints.VALUE_INTERPOLATION_NEAREST_NEIGHBOR));
    return hints;
    } // End getSpeedRenderingHints()

  /**
   * Creates a rendering "hints" which has all hint values set for maximum
   * quality.
   *
   * @return A rendering hint which has all of the hint values set for
   * maximum quality.  To use:
   * <p>
   * <code>RenderingHints hints = GetHints.getQualityRenderingHints();</code>
   * <p>
   * Then load the hints with <code>g2D.setRenderingHints(hints);</code>
   * <code>System.out.println("SpeedHints="+speedHints.toString());</code>
   * <p>
   * Where <code>g2D</code> is a Graphics2D object.
   */
  public static RenderingHints getQualityRenderingHints()
    {
    RenderingHints hints = new RenderingHints(RenderingHints.KEY_ANTIALIASING,
                               RenderingHints.VALUE_ANTIALIAS_ON);
    hints.add(new RenderingHints(RenderingHints.KEY_ALPHA_INTERPOLATION,
                                 RenderingHints.VALUE_ALPHA_INTERPOLATION_QUALITY));
    hints.add(new RenderingHints(RenderingHints.KEY_RENDERING,
                                 RenderingHints.VALUE_RENDER_QUALITY));
    hints.add(new RenderingHints(RenderingHints.KEY_DITHERING,
                                 RenderingHints.VALUE_DITHER_ENABLE));
    hints.add(new RenderingHints(RenderingHints.KEY_COLOR_RENDERING,
                                 RenderingHints.VALUE_RENDER_QUALITY));
    hints.add(new RenderingHints(RenderingHints.KEY_FRACTIONALMETRICS,
                                 RenderingHints.VALUE_FRACTIONALMETRICS_ON));
    hints.add(new RenderingHints(RenderingHints.KEY_TEXT_ANTIALIASING,
                                 RenderingHints.VALUE_TEXT_ANTIALIAS_ON));
    hints.add(new RenderingHints(RenderingHints.KEY_INTERPOLATION,
                                 RenderingHints.VALUE_INTERPOLATION_BICUBIC));
    return hints;
    } // End getQualityRenderingHints()


  /**
   * Returns the name of the class.
   *
   * @return The name of the class - getHints and rendering hints.
   * <p>
   * For example:
   * <p>
   * Hints={Alpha blending interpolation method key=Highest quality alpha
   *  blending methods, Image interpolation method key=Bicubic image
   *  interpolation mode, Global antialiasing enable key=Antialiased
   *  rendering mode, Fractional metrics enable key=Fractional text
   *  metrics mode, Dithering quality key=Dithered rendering mode,
   *  Color rendering quality key=Highest quality rendering methods,
   *  Global rendering quality key=Highest quality rendering methods
   *  Text-specific antialiasing enable key=Antialiased text mode}

   */
  public String toString()
    { return "Hints="+this.getQualityRenderingHints(); }

} // End GetHints class
