package fwpUtil;

import java.awt.*;
import javax.swing.*;
import java.awt.BorderLayout;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.Font;
import fwpUtil.Logger;
import java.io.IOException;

/**
 * Title: A basic HTML viewer.
 * </p>
 * <p>Description: This code displays a basic HTML viewer with a vertical
 * scroll bar.  It does not support hyperlinks and other more advanced features.
 * Its purpose is to display small to modest size html help files from within
 * an application program.</p>
 * <p>
 * Copyright: Copyright (c) 2011
 * <p>
 * Company: This code is placed in the public domain for un-restricted use.
 * The user is totally responsible for verifying the correct operation of
 * the code, or adapted code, in their application.</p>
 *
 * @author Fred Pospeschil
 * <p>
 * @version 1.0
 */
public class HTMLviewer extends JDialog
  {
  private JPanel       panel         = new JPanel();
  private BorderLayout borderLayout1 = new BorderLayout();
  private JButton      jButtonDone   = new JButton();
  private JScrollPane  jScrollPane   = new JScrollPane();
  private JEditorPane  HTMLPane      = new JEditorPane();
  private JPanel       jPanelSouth   = new JPanel();
  private String       filePath;
  private String       fileName;

/**
 * A basic viewer for disk based HTML files which does not support hypertext
 * links.  The constructor concatinates
 * the string "file:" in front of the filePath + fileName strings to form
 * the URL which is used to load the HTML file.  As a result, this routine
 * can only be used for loading files from local/network disks.  It's
 * intended purpose is for viewinglocal disk based help files.
 * <p>
 *The filePath\fileName string is displayed in the <code>Dialog</code> title bar.
 * <p>
 * When building the filePath string, suggest using:
 *<p>
 * <code>filePath = System.getProperty("user.dir") +"\\";</code>
 * <p>
 * or
 *<p>
 *<code>filePath = System.getProperty("user.dir")
 *                            + System.getProperty("file.separator");</code>
 *<p>
 *A valid URL would be <code>file:c:\MicroMap\MicorMapLog.html</code>
 *<p>
 * @param filePath The full path to the HTML file ending with a file seperator.
 *<p>
 * @param fileName The full file name with .html or .htm extension
 *
 */
  public HTMLviewer(String filePath, String fileName)
    {
    super.setTitle( filePath + fileName);
    this.filePath = filePath;
    this.fileName = fileName;
    try
      {
      Logger.writeLog(Logger.CONFIG, "HTMLviewer constructor entered");
      setDefaultCloseOperation(DISPOSE_ON_CLOSE);
      jbInit( filePath, fileName);     // Initialize the components
      }
    catch (Exception exception)        // Handle any exception
      { exception.printStackTrace(); } // Stack trace will go into log file
    Logger.writeLog(Logger.CONFIG, "HTMLviewer constructor exited");
    } // END HTMLviewer for other than Dialog or Frame

//##############################################################################
  private void jbInit( String filePath, String fileName) throws Exception
    {
    Logger.writeLog(Logger.CONFIG, "HTMLviewer jbInit entered");
    // JBuilder IDE generated code
    panel.setLayout(borderLayout1);
    jButtonDone.setFont(new java.awt.Font("Tahoma", Font.BOLD, 12));
    jButtonDone.setText("Done");
    jButtonDone.addActionListener(new ActionListener()
      {
      public void actionPerformed(ActionEvent e)
      { jButtonDone_actionPerformed(e); }
      });
    jScrollPane.setHorizontalScrollBarPolicy(JScrollPane.
        HORIZONTAL_SCROLLBAR_AS_NEEDED);
    jScrollPane.setVerticalScrollBarPolicy(JScrollPane.
        VERTICAL_SCROLLBAR_AS_NEEDED);
    getContentPane().add(panel);
    panel.add(jScrollPane, java.awt.BorderLayout.CENTER);
    jScrollPane.getViewport().add(HTMLPane);
    panel.add(jPanelSouth, java.awt.BorderLayout.SOUTH);
    jPanelSouth.add(jButtonDone);
    // End of JBuilder IDE generated code

    // Here is where the HTML is actually loaded
    Logger.writeLog(Logger.FINE, "Loading file " + filePath + fileName);
    // Have to set editable to false or hyperlinks will not be processed
    HTMLPane.setEditable(false);
    // The setPage loads a HTML file into the editor pane based on the URL
    // it is passed.  For local disk files the URL is a string in the form:
    // "file:C:\PathName\FileName.htm" (or .html)
    try
      {
      HTMLPane.setPage("file:" + filePath + fileName);
      Logger.writeLog(Logger.FINE,
                      "File " + filePath + fileName + " loaded");

      pack(); // Pack the dialog window
      this.setLocation(25, 25); // Put the window in the upper left of screen
      this.setSize(500, 400); // Keep the size of the widow reasonably small
      this.setVisible(true); // Now, show the darn thing
      }
    catch (IOException e)
      {
      Logger.writeLog(Logger.SEVERE,
                      "TextViewer jbInit IOException entered");
      Logger.writeLog(Logger.SEVERE, "Unable to open file "
                      + filePath + fileName);
      JOptionPane.showMessageDialog(null,
                                    "In HTMLviewer - Unable to open file "
                                    + filePath +
                                    fileName,
                                    "File Open Error",
                                    JOptionPane.ERROR_MESSAGE);
      e.printStackTrace();
      } // END catch

    Logger.writeLog(Logger.CONFIG, "HTMLviewer jbInit exited");
    } // END jbInit

//##############################################################################
  private void jButtonDone_actionPerformed(ActionEvent e)
    {
    Logger.writeLog(Logger.CONFIG, "HTMLviewer jButtonDone_actionPerformed");
    dispose();
    }

//##############################################################################
  /**
   * Returns the name of the class.
   *
   * @return The name of the class - HTMLviewer  plus the path and file
   * name of the HTMLviewer help file.
   */
  public String toString()
    { return "HTMLviewer " + filePath + " " + fileName; }

  } // END class HTMLviewer
