package fwpUtil;

import java.awt.*;
import javax.swing.*;
import java.awt.BorderLayout;
import javax.swing.border.Border;
import javax.swing.border.BevelBorder;
import javax.swing.border.TitledBorder;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import java.awt.Dimension;
import javax.swing.BorderFactory;
import java.awt.Color;
import java.awt.event.MouseAdapter;
import java.awt.event.MouseEvent;
import javax.swing.event.ChangeListener;
import javax.swing.event.ChangeEvent;
import fwpUtil.*;

/**
 * Title: Line style and color chooser dialog.</p>
 * <p>
 * Description: This control allows the user to fully specify how a line is
 * to be rendered/displayed.  It integrates the fairly standard color chooser
 * which allows specifying the color by using swatches, HSB or RGB tabs.
 * The line style selections include line end styles of Butt, Round or Square.
 * The line join styles include Bevel, Miter and Round.  The user can also
 * select whether the line is to be rendered using high quality or high speed
 * attributes.  The user can select between twenty line dash patterns and
 * specify the line width and transparency.  As each attribute is changed an
 * example line is updated to display how all of the currently selected
 * attributes affect the appearance of the line.
 * <p>
 * The control also provides for updating a Graphics2D object with new
 * color, rendering hints, and stroke parameters with only a single method call.
 * <p>
 * Copyright: Copyright (c) 2011
 *
 * @author Fred Pospeschil - This file is placed in the public domain
 * and can be used and adapted without restrictions.  The user of the code is
 * totally responsible for insuring its suitability in the intended application.
 * @version 1.0 - 2011
 */
public class LineAndColorChooser extends JDialog  implements ActionListener
  {
private   JPanel        contextPanel             = new JPanel();
private   BorderLayout  borderLayout1            = new BorderLayout();
private   JPanel        colorPanel               = new JPanel();
private   JColorChooser colorChooser;
private   Color         newColor                 = new Color(155,155,155,255);
private   Color         newAlphaColor;
private   Float         newLineWidth             = 1.0f;
private   int           newEndCap;
private   int           newEndMiter;
private   int           newWidth;
private   int           newAlpha                 = 255;
private   BasicStroke   newStroke;
private   RenderingHints newRenderingHints;
private   boolean       renderingLow             = true;
private   float[]       newDashPattern;
private   float[]       dashPattern01            = new float[]{10,0};
private   float[]       dashPattern02            = new float[]{2,2};
private   float[]       dashPattern03            = new float[]{2,4};
private   float[]       dashPattern04            = new float[]{2,8};
private   float[]       dashPattern05            = new float[]{4,4};
private   float[]       dashPattern06            = new float[]{4,8};
private   float[]       dashPattern07            = new float[]{4,16};
private   float[]       dashPattern08            = new float[]{4,4,12,4};
private   float[]       dashPattern09            = new float[]{8,8,24,8};
private   float[]       dashPattern10            = new float[]{12,12,4,12};
private   float[]       dashPattern11            = new float[]{4,4,8,8,4,4};
private   float[]       dashPattern12            = new float[]{8,8,16,8};
private   float[]       dashPattern13            = new float[]{14,14,14,14,28,14};
private   float[]       dashPattern14            = new float[]{8,8,8,8,16,8};
private   float[]       dashPattern15            = new float[]{4,4,8,4,16,4,8,4,4,4};
private   float[]       dashPattern16            = new float[]{2,2,4,2,8,2,4,2,2,2};
private   float[]       dashPattern17            = new float[]{2,2,4,2,6,2,8,2,6,2,4,2};
private   float[]       dashPattern18            = new float[]{3,3,6,3,12,3,6,3};
private   float[]       dashPattern19            = new float[]{4,4,8,4,12,4,8,4};
private   float[]       dashPattern20            = new float[]{6,6,12,6,18,6,12,6};
private   JPanel        controlPanel             = new JPanel();
private   JButton       cancelButton             = new JButton();
private   JButton       OKButton                 = new JButton();
private   JPanel        linePanel;
private   Border        border1                  = BorderFactory.createLineBorder
                                           (SystemColor.controlText, 2);
private   Border        border2                  = BorderFactory.createBevelBorder
                                           (BevelBorder.LOWERED,
                                           Color.white, Color.white,
                                           new Color(103, 101, 98),
                                           new Color(148, 145, 140));
private   Border        border3                  = BorderFactory.createBevelBorder
                                           (BevelBorder.RAISED,
                                           Color.white, Color.white,
                                           new Color(103, 101, 98),
                                           new Color(148, 145, 140));
private   Border        border4                  = BorderFactory.createBevelBorder
                                           (BevelBorder.RAISED,
                                           Color.white, Color.white,
                                           new Color(103, 101, 98),
                                           new Color(148, 145, 140));
private   Border        border5                  = new TitledBorder(border4,
                                           "Line Styles");
private   JPanel        attributesPanel          = new JPanel();
private   JLabel        endStylesLabel           = new JLabel();
private   JRadioButton  buttEndRadioButton       = new JRadioButton();
private   JRadioButton  roundJoinRadioButton     = new JRadioButton();
private   JRadioButton  squareEndRadioButton     = new JRadioButton();
private   JLabel        fillerLabel1             = new JLabel();
private   JLabel        joinLabel                = new JLabel();
private   ButtonGroup   buttonGroup1             = new ButtonGroup();
private   JRadioButton  bevelJoinRadioButton     = new JRadioButton();
private   JRadioButton  miterJoinRadioButton     = new JRadioButton();
private   JRadioButton  roundEndRadioButton      = new JRadioButton();
private   ButtonGroup   buttonGroup2             = new ButtonGroup();
private   JLabel        fillerLabel2             = new JLabel();
private   JLabel        imageQualityLabel        = new JLabel();
private   JRadioButton  lowQualityRadioButton    = new JRadioButton();
private   JRadioButton  highQualityRadioButton   = new JRadioButton();
private   JLabel        fillerLabel3             = new JLabel();
private   ButtonGroup   buttonGroup3             = new ButtonGroup();
private   JLabel        lineWidthLabel           = new JLabel();
private   JTextField    widthTextField           = new JTextField("1", 3);
private   Graphics2D    lp2D;
private   GridLayout    gridLayout1              = new GridLayout();
private   JRadioButton  dashButton01             = new JRadioButton();
private   JRadioButton  dashButton02             = new JRadioButton();
private   JRadioButton  dashButton03             = new JRadioButton();
private   JRadioButton  dashButton04             = new JRadioButton();
private   JRadioButton  dashButton05             = new JRadioButton();
private   JRadioButton  dashButton06             = new JRadioButton();
private   JRadioButton  dashButton07             = new JRadioButton();
private   JRadioButton  dashButton08             = new JRadioButton();
private   JRadioButton  dashButton09             = new JRadioButton();
private   JRadioButton  dashButton10             = new JRadioButton();
private   JRadioButton  dashButton11             = new JRadioButton();
private   JRadioButton  dashButton12             = new JRadioButton();
private   JRadioButton  dashButton13             = new JRadioButton();
private   JRadioButton  dashButton14             = new JRadioButton();
private   JRadioButton  dashButton15             = new JRadioButton();
private   JRadioButton  dashButton16             = new JRadioButton();
private   JRadioButton  dashButton17             = new JRadioButton();
private   JRadioButton  dashButton18             = new JRadioButton();
private   JRadioButton  dashButton19             = new JRadioButton();
private   JRadioButton  dashButton20             = new JRadioButton();
private   JLabel        fillerLabel4             = new JLabel();
private   JLabel        alphaLabel               = new JLabel();
private   JTextField    alphaTextField           = new JTextField();
private   GridLayout    gridLayout2              = new GridLayout();
private   ButtonGroup   buttonGroup4             = new ButtonGroup();

//------------------------------------------------------------------------------
/**
 * Line style and color chooser dialog.
 *
 * @param parent The frame or subclass of frame from which this object
 * is being created.  This dialog will be centered on the parent.  If
 * a null is passed as the parent the dialog will be positioned 20 pixels
 * down and to the right of the upper left corner of the display.
 * <p>
 * The dialog title will be "Line and Color Chooser" and the dialog will
 * be modal.
 */
  public LineAndColorChooser(Frame parent) {
    super(parent, "Line and Color Chooser", true);
    try {
      setDefaultCloseOperation(DISPOSE_ON_CLOSE);
      jbInit(parent);
      pack();
    }
    catch (Exception exception) {
      exception.printStackTrace();
    }
  } // End LineAndColorChooser constructor

//------------------------------------------------------------------------------
  private void jbInit(Frame parent) throws Exception {
    this.setSize(480, 770);
    border5 = new TitledBorder(BorderFactory.createLineBorder(Color.black,
        2), "Line Dash Patterns");
    border1 = new TitledBorder(BorderFactory.createLineBorder(SystemColor.
        controlText, 1), "Color Settings");
    this.setResizable(true);

    // Set up the color chooser panel and attach a change listener so that color
    // updates get reflected in our preview label.
    colorPanel.setBorder(border1);
//    colorPanel.setMinimumSize(new Dimension(434, 350));
    colorChooser = new JColorChooser(Color.black);
//    colorChooser.setPreferredSize(new Dimension(434, 335));
    colorChooser.getSelectionModel()
                .addChangeListener(new ChangeListener() {
    public void stateChanged(ChangeEvent e) {
      newColor = colorChooser.getColor();
      linePanel.repaint();
      } });

    // Handle the Cancel and OK buttons. =======================================
    cancelButton.setText("Cancel");
    cancelButton.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
        setVisible(false); } });

    OKButton.setText("OK");
    OKButton.addActionListener(new ActionListener() {
      public void actionPerformed(ActionEvent e) {
 //       setVisible(false);
     OKButton_actionPerformed(e);
      } });

    // Handle the end caps radio buttons ======================================
    roundEndRadioButton.setMinimumSize(new Dimension(67, 25));
    roundEndRadioButton.setPreferredSize(new Dimension(65, 15));
    roundEndRadioButton.setToolTipText(
        "Select this for rounded ends on the lines");
    roundEndRadioButton.setHorizontalAlignment(SwingConstants.LEFT);
    roundEndRadioButton.setText("Round ");
    roundEndRadioButton.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
      newEndCap = BasicStroke.CAP_ROUND;
      linePanel.repaint(); } });

    buttEndRadioButton.setText("Butt     ");
    buttEndRadioButton.setToolTipText(
        "Select this for square ends on the lines");
    buttEndRadioButton.setPreferredSize(new Dimension(63, 15));
    buttEndRadioButton.setHorizontalAlignment(SwingConstants.LEFT);
    buttEndRadioButton.setSelected(true);
    buttEndRadioButton.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent mouseEvent) {
      newEndCap = BasicStroke.CAP_BUTT;
      linePanel.repaint(); } });

    squareEndRadioButton.setText("Square");
    squareEndRadioButton.setToolTipText(
        "Select this for extended square ends on the lines");
    squareEndRadioButton.setPreferredSize(new Dimension(67, 15));
    squareEndRadioButton.setHorizontalAlignment(SwingConstants.LEFT);
    squareEndRadioButton.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newEndCap = BasicStroke.CAP_SQUARE;
        linePanel.repaint(); } });

    // Handle the line dash pattern radio buttons =============================
    dashButton01.setOpaque(false);
    dashButton01.setPreferredSize(new Dimension(45, 25));
    dashButton01.setSelected(true);
    dashButton01.setText("01");
    dashButton01.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern01;
        linePanel.repaint(); } });

    dashButton02.setOpaque(false);
    dashButton02.setText("02");
    dashButton02.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern02;
        linePanel.repaint(); } });

    dashButton03.setOpaque(false);
    dashButton03.setText("03");
    dashButton03.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern03;
        linePanel.repaint(); } });

    dashButton04.setOpaque(false);
    dashButton04.setText("04");
    dashButton04.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern04;
        linePanel.repaint(); } });

    dashButton05.setOpaque(false);
    dashButton05.setText("05");
    dashButton05.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern05;
        linePanel.repaint(); } });

    dashButton06.setOpaque(false);
    dashButton06.setText("06");
    dashButton06.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern06;
        linePanel.repaint(); } });

    dashButton07.setOpaque(false);
    dashButton07.setText("07");
    dashButton07.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern07;
        linePanel.repaint(); } });

    dashButton08.setOpaque(false);
    dashButton08.setText("08");
    dashButton08.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern08;
        linePanel.repaint(); } });

    dashButton09.setOpaque(false);
    dashButton09.setText("09");
    dashButton09.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern09;
        linePanel.repaint(); } });

    dashButton10.setOpaque(false);
    dashButton10.setRequestFocusEnabled(false);
    dashButton10.setText("10");
    dashButton10.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern10;
        linePanel.repaint(); } });

    dashButton11.setOpaque(false);
    dashButton11.setRequestFocusEnabled(false);
    dashButton11.setText("11");
    dashButton11.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern11;
        linePanel.repaint(); } });

    dashButton12.setOpaque(false);
    dashButton12.setText("12");
    dashButton12.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern12;
        linePanel.repaint(); } });

    dashButton13.setOpaque(false);
    dashButton13.setText("13");
    dashButton13.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern13;
        linePanel.repaint(); } });

    dashButton14.setOpaque(false);
    dashButton14.setText("14");
    dashButton14.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern14;
        linePanel.repaint(); } });

    dashButton15.setOpaque(false);
    dashButton15.setText("15");
    dashButton15.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern15;
        linePanel.repaint(); } });

    dashButton16.setOpaque(false);
    dashButton16.setText("16");
    dashButton16.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern16;
        linePanel.repaint(); } });

    dashButton17.setOpaque(false);
    dashButton17.setText("17");
    dashButton17.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern17;
        linePanel.repaint(); } });

    dashButton18.setOpaque(false);
    dashButton18.setText("18");
    dashButton18.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern18;
        linePanel.repaint(); } });

    dashButton19.setOpaque(false);
    dashButton19.setText("19");
    dashButton19.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern19;
        linePanel.repaint(); } });

    dashButton20.setOpaque(false);
    dashButton20.setText("20");
    dashButton20.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        newDashPattern = dashPattern20;
        linePanel.repaint(); } });
    lowQualityRadioButton.setToolTipText(
        "Select this for lower image quality but higer drawing speed");
    lowQualityRadioButton.setPreferredSize(new Dimension(49, 15));
    lowQualityRadioButton.setHorizontalAlignment(SwingConstants.LEFT);
    lowQualityRadioButton.setSelected(true);
    lowQualityRadioButton.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        renderingLow = true;
        linePanel.repaint(); } });

    highQualityRadioButton.setText("High");
    highQualityRadioButton.setToolTipText(
        "Select this for higher image quality but lower drawing speed");
    highQualityRadioButton.setPreferredSize(new Dimension(51, 15));
    highQualityRadioButton.setHorizontalAlignment(SwingConstants.LEFT);
    highQualityRadioButton.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
        renderingLow = false;
        linePanel.repaint(); } });

    // Handle the line joins radio buttons ====================================
    roundJoinRadioButton.setText("Round ");
    roundJoinRadioButton.setToolTipText(
        "Select this to have lines joined with round ends");
    roundJoinRadioButton.setPreferredSize(new Dimension(69, 15));
    roundJoinRadioButton.setHorizontalAlignment(SwingConstants.LEFT);
    roundJoinRadioButton.setActionCommand("RoundJoin ");
    roundJoinRadioButton.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
      newEndMiter = BasicStroke.JOIN_ROUND;
      linePanel.repaint(); }});

    bevelJoinRadioButton.setText("Bevel   ");
    bevelJoinRadioButton.setToolTipText(
        "Select this to have lines joined with beveled ends");
    bevelJoinRadioButton.setPreferredSize(new Dimension(67, 15));
    bevelJoinRadioButton.setHorizontalAlignment(SwingConstants.LEFT);
    bevelJoinRadioButton.setSelected(true);
    bevelJoinRadioButton.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
      newEndMiter = BasicStroke.JOIN_BEVEL;
      linePanel.repaint(); }});

    miterJoinRadioButton.setText("Miter   ");
    miterJoinRadioButton.setToolTipText(
        "Select this to have lines joined with mitered  ends");
    miterJoinRadioButton.setPreferredSize(new Dimension(67, 15));
    miterJoinRadioButton.setHorizontalAlignment(SwingConstants.LEFT);
    miterJoinRadioButton.addMouseListener(new MouseAdapter() {
      public void mouseClicked(MouseEvent e) {
      newEndMiter = BasicStroke.JOIN_MITER;
      linePanel.repaint(); } });

    fillerLabel4.setPreferredSize(new Dimension(4, 8));
    fillerLabel4.setText(" ");

    // Handle the alpha/transparency text input field =========================
    alphaLabel.setHorizontalAlignment(SwingConstants.LEFT);
    alphaLabel.setText("Alpha");
    alphaTextField.setText("255");
    alphaTextField.setColumns(3);
    alphaTextField.setActionCommand("alphaTextField");
    alphaTextField.addActionListener(this);

    // Handle the line width text input field =================================
    widthTextField.setColumns(1);
    widthTextField.setText("1");
    widthTextField.setPreferredSize(new Dimension(17, 22));
    widthTextField.setActionCommand("widthTextField");
    widthTextField.addActionListener(this);

    gridLayout2.setColumns(1);
    gridLayout2.setRows(20);


    colorPanel.add(colorChooser, BorderLayout.CENTER);

    attributesPanel.setLayout(gridLayout2);
//    attributesPanel.setMinimumSize(new Dimension(106, 400));
    attributesPanel.setPreferredSize(new Dimension(79, 280));

    endStylesLabel.setText("End Styles");
    endStylesLabel.setPreferredSize(new Dimension(59, 15));
    endStylesLabel.setHorizontalAlignment(SwingConstants.LEFT);
    fillerLabel1.setText("  ");
    fillerLabel1.setPreferredSize(new Dimension(96, 2));
    joinLabel.setText("Join Styles");
    joinLabel.setPreferredSize(new Dimension(64, 16));
    joinLabel.setHorizontalAlignment(SwingConstants.LEFT);
    fillerLabel2.setText(" ");
    fillerLabel2.setMinimumSize(new Dimension(4, 10));
    fillerLabel2.setPreferredSize(new Dimension(12, 2));
    imageQualityLabel.setText("Line Quality");
    imageQualityLabel.setHorizontalAlignment(SwingConstants.LEFT);
    fillerLabel3.setText(" ");
    fillerLabel3.setPreferredSize(new Dimension(4, 2));
    lineWidthLabel.setText("Line Width");
    lineWidthLabel.setPreferredSize(new Dimension(60, 16));
    lineWidthLabel.setHorizontalAlignment(SwingConstants.LEFT);
    controlPanel.setBorder(border2);
    controlPanel.add(OKButton);
    controlPanel.add(cancelButton);

    contextPanel.setLayout(borderLayout1);
    contextPanel.add(colorPanel, java.awt.BorderLayout.NORTH);
    linePanel = new LineDisplay();
    linePanel.setLayout(gridLayout1);
    linePanel.setPreferredSize(new Dimension(355, 325));
    gridLayout1.setColumns(1);
    gridLayout1.setRows(20);
    contextPanel.add(linePanel, java.awt.BorderLayout.CENTER);
    contextPanel.add(attributesPanel, java.awt.BorderLayout.EAST);
    contextPanel.add(controlPanel, java.awt.BorderLayout.SOUTH);
    getContentPane().add(contextPanel);

    linePanel.add(dashButton01);
    linePanel.add(dashButton02);
    linePanel.add(dashButton03);
    linePanel.add(dashButton04);
    linePanel.add(dashButton05);
    linePanel.add(dashButton06);
    linePanel.add(dashButton07);
    linePanel.add(dashButton08);
    linePanel.add(dashButton09);
    linePanel.add(dashButton10);
    linePanel.add(dashButton11);
    linePanel.add(dashButton12);
    linePanel.add(dashButton13);
    linePanel.add(dashButton14);
    linePanel.add(dashButton15);
    linePanel.add(dashButton16);
    linePanel.add(dashButton17);
    linePanel.add(dashButton18);
    linePanel.add(dashButton19);
    linePanel.add(dashButton20);

    buttonGroup1.add(buttEndRadioButton);
    buttonGroup1.add(squareEndRadioButton);
    buttonGroup1.add(roundEndRadioButton);
    buttonGroup2.add(bevelJoinRadioButton);
    buttonGroup2.add(miterJoinRadioButton);
    buttonGroup2.add(roundJoinRadioButton);
    buttonGroup3.add(lowQualityRadioButton);
    buttonGroup3.add(highQualityRadioButton);
    attributesPanel.add(endStylesLabel, null);
    attributesPanel.add(buttEndRadioButton, null);
    attributesPanel.add(roundEndRadioButton, null);
    attributesPanel.add(squareEndRadioButton, null);
    attributesPanel.add(fillerLabel1, null);
    attributesPanel.add(joinLabel, null);
    attributesPanel.add(bevelJoinRadioButton, null);
    attributesPanel.add(miterJoinRadioButton, null);
    attributesPanel.add(roundJoinRadioButton, null);
    attributesPanel.add(fillerLabel2, null);
    attributesPanel.add(imageQualityLabel, null);
    attributesPanel.add(lowQualityRadioButton, null);
    attributesPanel.add(highQualityRadioButton, null);
    attributesPanel.add(fillerLabel3, null);
    attributesPanel.add(lineWidthLabel, null);
    attributesPanel.add(widthTextField, null);
    attributesPanel.add(fillerLabel4, null);
    attributesPanel.add(alphaLabel, null);
    attributesPanel.add(alphaTextField, null);
    linePanel.setBorder(border5);
    buttonGroup4.add(dashButton01);
    buttonGroup4.add(dashButton02);
    buttonGroup4.add(dashButton03);
    buttonGroup4.add(dashButton04);
    buttonGroup4.add(dashButton05);
    buttonGroup4.add(dashButton06);
    buttonGroup4.add(dashButton07);
    buttonGroup4.add(dashButton08);
    buttonGroup4.add(dashButton09);
    buttonGroup4.add(dashButton10);
    buttonGroup4.add(dashButton11);
    buttonGroup4.add(dashButton12);
    buttonGroup4.add(dashButton13);
    buttonGroup4.add(dashButton14);
    buttonGroup4.add(dashButton15);
    buttonGroup4.add(dashButton16);
    buttonGroup4.add(dashButton17);
    buttonGroup4.add(dashButton18);
    buttonGroup4.add(dashButton19);
    buttonGroup4.add(dashButton20);

   // Position the dialog
   if (parent == null)
     { // If there is no parent then position the dialog at the upper left
     this.setLocation(20, 20);
     }
   else
     { // Else position the dialog over the center of the parent
     Dimension dlgSize = this.getPreferredSize();
     Dimension frmSize = parent.getSize();
     Point loc = parent.getLocation();
     this.setLocation( (frmSize.width - dlgSize.width) / 2 + loc.x,
                      (frmSize.height - dlgSize.height) / 2 + loc.y);
     }
  newAlphaColor = new Color(123,125,127,255);
  this.pack();
  setVisible(true);
  } // End jbInit

//------------------------------------------------------------------------------
// This class is based heavily on Java 2D Graphics by Jonathan Knudsen,
//  O'Reilly publishers pgs 275- 303.
// An object of this class will be to over-ride the linePanel
// paintComponent method anytime the linePanel needs to be repainte.
//
// The operative statements is:
//    lineDisplay = new LineDisplay();
  private class LineDisplay extends JPanel
    {
    protected void paintComponent (Graphics g)
      {
      super.paintComponent(g); // Let the JPanel super class do its thing
      // Create a local Graphics2D so we don't clopper the one passed in
      Graphics2D g2d = (Graphics2D)g.create();
      drawLines(g2d); // Draw the map
      // Now we are done with the g2d so we can get rid of it
      g2d.dispose(); // Now we are done with the g2d so we can get rid of it
      } // End paintComponent
    } // End class MapDisplay

//------------------------------------------------------------------------------
  // Draw all of the lines which are displayed in the "Line Dash Patterns" area.
  private void drawLines(Graphics2D g)
    {
    lp2D = (Graphics2D)g;
    // Draw white horizontal box at the bottom of the panel
    lp2D.setStroke(new BasicStroke(45));
    lp2D.setColor(Color.white);
    lp2D.drawLine(150,230,300,230);

    // Draw the horizontal dash patterns
    lp2D.setColor(newColor); // do not want alpha to play here
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern01,0));
    lp2D.drawLine(45,29,250,29);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern02,0));
    lp2D.drawLine(45,42,250,42);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern03,0));
    lp2D.drawLine(45,56,250,56);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern04,0));
    lp2D.drawLine(45,70,250,70);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern05,0));
    lp2D.drawLine(45,84,250,84);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern06,0));
    lp2D.drawLine(45,98,250,98);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern07,0));
    lp2D.drawLine(45,112,250,112);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern08,0));
    lp2D.drawLine(45,126,250,126);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern09,0));
    lp2D.drawLine(45,140,250,140);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern10,0));
    lp2D.drawLine(45,156,250,156);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern11,0));
    lp2D.drawLine(45,170,250,170);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern12,0));
    lp2D.drawLine(45,184,250,184);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern13,0));
    lp2D.drawLine(45,198,250,198);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern14,0));
    lp2D.drawLine(45,212,250,212);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern15,0));
    lp2D.drawLine(45,226,250,226);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern16,0));
    lp2D.drawLine(45,240,250,240);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern17,0));
    lp2D.drawLine(45,254,250,254);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern18,0));
    lp2D.drawLine(45,268,250,268);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern19,0));
    lp2D.drawLine(45,281,250,281);
    lp2D.setStroke(new BasicStroke(1,1,1,1,dashPattern20,0));
    lp2D.drawLine(45,294,250,294);


    if (renderingLow)
      newRenderingHints = GetHints.getSpeedRenderingHints();
    else
      newRenderingHints = GetHints.getQualityRenderingHints();
    lp2D.setRenderingHints(newRenderingHints);

    // Get the individual colors from the newColor
    int red   = newColor.getRed();
    int green = newColor.getGreen();
    int blue  = newColor.getBlue();
    // Now build new color using the rgb and alpha values
    newAlphaColor = new Color(red,green,blue,newAlpha);
    this.newAlphaColor = new Color(red,green,blue,newAlpha);
    lp2D.setColor(newAlphaColor);
    newStroke = new BasicStroke(newLineWidth,   //Line width
                                newEndCap,      // End Cap style
                                newEndMiter,    // End Miter style
                                10f,             // Miter limit
                                newDashPattern, // Dash pattern
                                0);             // Dash phase
    lp2D.setStroke(newStroke);
    int[] xCoords = new int[]{150,160,120,300,300,340,260,260,350};
    int[] yCoords = new int[]{230,200,248,230,200,200,300,150, 20};
    lp2D.drawPolyline(xCoords , yCoords, 9);
    } // End drawLines

//------------------------------------------------------------------------------
  // Process the changed line width value
  public void actionPerformed(ActionEvent ae)
    {
    String actionCommand = ae.getActionCommand();
    // Process updates to the line width text input field.
    if (actionCommand.equals("widthTextField"))
      {
      String width = widthTextField.getText();
      newLineWidth = Float.valueOf(width) * 0.1f;
      // The line width value must be positive
      if (newLineWidth < 0.0)
        {
        newLineWidth = 0.1f;
        widthTextField.setText("1");
        JOptionPane.showMessageDialog(contextPanel,
                 "  The line width must be at least 1." +
               "\n       It cannot be negative." +
               "\n The program has reset the width to 1.",
               "The line width was in error.",
               JOptionPane.WARNING_MESSAGE);
        }
      linePanel.repaint();
      return;
      }
    // Process updates to the alpha text input field.
    if (actionCommand.equals("alphaTextField"))
      {
      String alpha = alphaTextField.getText();
      newAlpha = Integer.valueOf(alpha);
      // The alpha value must be between 1 and 255
      if (newAlpha < 1 || newAlpha > 255)
        {
        newAlpha = 255;
        alphaTextField.setText("255");
        JOptionPane.showMessageDialog(contextPanel,
               "The alpha transparency value must be between 1 and 255." +
             "\n        The program has reset the width to 255.",
             "The alpha value was in error.",
             JOptionPane.WARNING_MESSAGE);
        }
      linePanel.repaint();
      return;
      }
    } // End actionPerformed(ActionEvent ae)

//------------------------------------------------------------------------------
  private void OKButton_actionPerformed(ActionEvent e)
    {
    setVisible(false);
    }

  private void cancelButton_actionPerformed(ActionEvent e)
    {
    newAlphaColor = null;
    newStroke = null;
    setVisible(false);
    }

/**
 * Returns the color and transparency value that were selected by the user.
 *
 * @return A Color object with red, green, blue and alpha set.  The
 * alpha/transparency value is constrained to fall beween (inclusive)
 * 1 and 255.  If an invalid value is entered the program advises the
 * user and sets the value to 255.  The user then has the opportunity to
 * enter another legal value.
 */
  public Color getNewColor()
    { return newAlphaColor; }

/**
 * Returns the stroke that the user developed.
 *
 * @return A Stroke object. The stroke parameters set by the user include the
 * line width, end cap style, line join style and dash pattern.  The miter
 * limit is set to 10 and the dash phase is set to 0.
 * <p>
 * The GUI provides for selecting from twenty different dash patterns.
 * <p>
 * If the user enters a negative line width value the program issues a
 * warning and resets the value to 1.  The actual line width returned is
 * the value entered by the user divided by 10.  This was thought to make
 * it easier for the user to specify very thin lines with out having to
 * work with entering decimal numbers.  Experimentation found that a line
 * width of 1 (0.1) was the finest line which had any real visability on the
 * monitor or printers - using 300 through 1200 DPI settings.
 */
  public BasicStroke getNewStroke()
    { return newStroke; }

  public RenderingHints getRenderingHints()
    { return newRenderingHints; }

/**
 * Update the graphics 2D object with new rendering hints, RGB color with
 * transparency and stroke. The stroke will contain new line width, end caps,
 * line join and dash pattern.  The miter limit is set to 10 and the dash
 * phase is set to 0.
 *
 * @param g2D The graphics object which should be updated.
 */
  public void updateG2D(Graphics2D g2D)
    {
    g2D.setRenderingHints(newRenderingHints);
    g2D.setColor(newAlphaColor);
    g2D.setStroke(newStroke);
    return;
    }


  private Graphics2D g;
/**
 * Returns string values of the g2D, rendering hints, stroke, and color alpha.
 * <p>
 * Example:
 * <p>
 * g2D=sun.java2d.SunGraphics2D[font=javax.swing.plaf.FontUIResource
 * [family=Tahoma,name=Tahoma,style=plain,size=13],color=java.awt.Color
 * [r=51,g=0,b=255]] Rendering Hints={Alpha blending interpolation method
 * key=Fastest alpha blending methods, Image interpolation method
 * key=Nearest Neighbor image interpolation mode,
 * Global antialiasing enable key=Nonantialiased rendering mode,
 * Fractional metrics enable key=Integer text metrics mode, Dithering quality key=Nondithered rendering mode, Color rendering quality key=Fastest rendering methods, Global rendering quality key=Fastest rendering methods, Text-specific antialiasing enable key=Nonantialiased text mode}
 * Stroke=java.awt.BasicStroke@783db174 Alpha=255
 * @param g2D The graphics object which should be updated.
 */
  public String toString()
    {
    return "g2D="+lp2D.toString()
      + "\n Rendering Hints="+newRenderingHints
      + "\n Stroke="+ newStroke
      + "\n Alpha="+newAlpha;
    }

  } // End LineAndColorChooser
