 package fwpUtil;

import java.awt.*;
import javax.swing.*;
import java.awt.BorderLayout;
import java.awt.Font;
import java.awt.Dimension;
import java.awt.Color;
import javax.swing.border.TitledBorder;
import java.awt.event.ActionListener;
import java.awt.event.ActionEvent;
import fwpUtil.*;

/**
 * Title: A dialog to setup and control logging actions within a program.
 * <p>
 * This is a small logger capability which was originally written in Pascal
 * and subsequently re-written in C, Ada and now Java.  Though vastly smaller
 * than the Java version, it performs the essential logging functions.  For
 * comapatibility the names of the logging levels were made the same as\
 * those used in the Java logger.
 * <p>
 * Under normal circumstances, a user will not have any reason to use the
 * functions supported by this dialog.  As you will see from the following
 * description, the capabilities provide here are of use primarily during
 * program development and testing.  However, they are also of critical use
 * when a user runs into a program error or malfunction.
 * <p>
 * When the users run into a problem, they need to record what they did to
 * create the problem.  In other words, they need to provide the program
 * developer with an accurate description of exactly what menu selections they
 * made, what keys they pressed, and what inputs they made.  This can be a
 * time consuming task, especially if there are several ways in which The
 *  error can be created.
 * <p>
 * The capabilities provided here make this a whole lot easier.  When the
 * program starts the logging function is ormally turned "OFF".  Should
 * the suer encounter a problem, or is curious about its internal operation;
 * they can come to this dialog and turn on the logging activities.
 * To see how this all works, the user simply performs the following steps:
 *<p>
 * 1.  Click the ALL radio button at the bottom the Log Levels radio buttons.
 * This will capture the maximum amount of internal information.  It will
 * also erase any old log file which may exist and start a new one.
 * <p>
 * 2.  Click the Read the log file button.  The log file display window will
 * display a list of actions which have taken place up to this point.
 * The list will look something like the following:
 * <p>
 * Default LogFile = C:\MicroMap\Log.txt
 * <p>
 * MainWindowFrame entering constructor
 * <p>
 * MainWindowFrame entering jbInit
 * <p>
 * MainWindowFrame exiting jbInit
 * <p>
 * MainWindowFrame exiting constructor
 * <p>
 * MainWindowFrame jMenuHelpLog_actionPerformed
 * <p>
 * LogIt entering constructor
 * <p>
 * LogIt entering jbInit
 * <p>
 * Logger getLogFilePath = C:\MicroMap\
 * <p>
 * Logger getLogFileName = Log.txt
 * <p>
 * Loading file C:\MicroMap\HelpFiles\LogFileHelp.htm
 * <p>
 * File C:\MicroMap\HelpFiles\LogFileHelp.htm loaded
 * <p>
 * LogIt jRadioALL_actionPerformed
 * <p>
 * LogIt jButtonReadLogFile_actionPerformed
 * <p>
 * TextViewer file load started.
 * <p>
 * Loading file C:\MicroMap\Log.txt<p>
 * <p>
 * This information can be very important when trying to figure out what went
 * wrong in the program.  Notice that the location and name of the log file
 * is displayed in the title bar of the window.
 * <p>
 * 2.  Click the Done button on the window.
 * <p>
 * 3.  Click the Add environment variables button.  This will add quite a
 * bit of internal system information to the log file.
 * <p>
 * 4.  Click the Read the log file button again.  Now the user will see that a
 * large amount of additional information is in the file.  Note: the viewer
 * always places the user at the end of the log file so they can automatically
 * see the most recent additions to the file.
 * <p>
 * 5.  Click the Done button again to close the window.
 * <p>
 * 6.  Click the OFF radio button to turn off the logging and then the Done
 * button to close the Program Logging window.
 * <p>
 * The user can turn the logging function on or off at any time during
 * their use of the program.  They can also change the level of logging
 * at any time.
 * </p>
 * A copy of the default LogItHelp.htm file is located in the fwpUtil package
 * directory.
 * <p>
 * Example usage:
 * <p>
 *     LogIt log = new LogIt();
 * <p>
    // Center the dialog on this parent window
 * <p>
    Dimension dlgSize = log.getSize();
 * <p>
    Dimension frmSize = this.getSize();
 * <p>
    Point loc = this.getLocation();
 * <p>
    log.setLocation( (frmSize.width - dlgSize.width) / 2 + loc.x,
 * <p>
                     (frmSize.height - dlgSize.height) / 2 + loc.y);
 * <p>
    log.setVisible(true);
 * <p>
    log = null;

 * <p>
 * Copyright: Copyright (c) 2011
 * </p>
 * @author Fred Pospeschil - This file is placed in the public domain
 * and can be used and adapted without restrictions.  The user of the code is
 * totally responsible for insuring its suitability in the intended application.
 * @version 1.0
 */

public class LogIt
    extends JDialog
  {
  private JLabel        jLabelTop                      = new JLabel();
  private JPanel        jPaneCenter                    = new JPanel();
  private JLabel        jLabelPathAndName              = new JLabel();
  private JLabel        jLabelPathName                 = new JLabel();
  private JButton       jButtonDone                    = new JButton();
  private JPanel        jPanelWest                     = new JPanel();
  private JRadioButton  jRadioINFO                     = new JRadioButton();
  private JRadioButton  jRadioWARNING                  = new JRadioButton();
  private JRadioButton  jRadioSEVERE                   = new JRadioButton();
  private JRadioButton  jRadioOFF                      = new JRadioButton();
  private ButtonGroup   buttonGroup1                   = new ButtonGroup();
  private JRadioButton  jRadioCONFIG                   = new JRadioButton();
  private JRadioButton  jRadioFINE                     = new JRadioButton();
  private JRadioButton  jRadioFINER                    = new JRadioButton();
  private JRadioButton  jRadioFINEST                   = new JRadioButton();
  private JRadioButton  jRadioALL                      = new JRadioButton();
  private TitledBorder  titledBorder1                  = new TitledBorder("");
  private JLabel        jLabelInfoSpacer               = new JLabel();
  private JButton       jButtonReadLogFile             = new JButton();
  private JButton       jButtonAddEnvironmentVariables = new JButton();
  private JButton       jButtonHelp                    = new JButton();
  private JLabel        jLabelSpacer2                  = new JLabel();
  private JLabel        jLabel2                        = new JLabel();
  private JLabel        jLabel3                        = new JLabel();
  private BorderLayout  borderLayout1                  = new BorderLayout();
  private GridBagLayout gridBagLayout2                 = new GridBagLayout();
  private GridBagLayout gridBagLayout1                 = new GridBagLayout();
  private JLabel        jLabel1                        = new JLabel();

  private static String logFilePath;
  private static String logFileName;
  private static String logHelpFilePath;
  private static String logHelpFileName;
  private static int    newLogLevel = Logger.OFF;
  private static String environmentVariable;
  private Frame  parent;

//##############################################################################
  /**
   * The Dialog allows the user to set the desired level of program data logging.
   * Thru this dialog the user can set the logging level to one of the following:
   * OFF, SEVERE, WARNING, INFO, CONFIG, FINE, FINER, FINEST, or ALL.
   * <p>
   * The dialog displays the full path\file name of the log file.
   * <p>
   * The user can also display the log and help files.
   * <p>
   * If a frame is provided, the dialog is centered over that frame.  Otherwise,
   * if a <code>null</code> is passed, the dialog is positioned 20 pixels down
   * and to the right of the upper left corner of the display screen.
   */
  public LogIt(Frame parent)
    {
    Logger.writeLog(Logger.CONFIG,"LogIt entering constuctor");
    try
      {
      this.parent = parent; // Save for use in jbInit
      setDefaultCloseOperation(DISPOSE_ON_CLOSE);
      jbInit();
      pack();
      }
    catch (Exception exception)
      { exception.printStackTrace(); }
    Logger.writeLog(Logger.CONFIG,"LogIt exiting constuctor");
    } // END LogIt


//##############################################################################
  private void jbInit() throws Exception
    {
    // JBuilder GUI generated code
    setTitle("Program Logging Control");
    Logger.writeLog(Logger.CONFIG,"LogIt entering jbInit");
    jLabelTop.setFont(new java.awt.Font("Tahoma", Font.BOLD, 14));
    jLabelTop.setHorizontalAlignment(SwingConstants.CENTER);
    jLabelTop.setHorizontalTextPosition(SwingConstants.CENTER);
    jLabelTop.setText("Program Logging Setup and Control");
    jLabelPathAndName.setToolTipText("");
    jLabelPathAndName.setHorizontalAlignment(SwingConstants.CENTER);
    jLabelPathAndName.setHorizontalTextPosition(SwingConstants.CENTER);
    jLabelPathAndName.setText("   Log File path and name");
    jLabelPathName.setFont(new java.awt.Font("Tahoma", Font.BOLD, 11));
    jLabelPathName.setForeground(Color.blue);
    jLabelPathName.setMaximumSize(new Dimension(50, 15));
    jLabelPathName.setMinimumSize(new Dimension(50, 15));
    jLabelPathName.setToolTipText(" ");
    jLabelPathName.setHorizontalAlignment(SwingConstants.CENTER);
    jLabelPathName.setHorizontalTextPosition(SwingConstants.CENTER);
    jButtonDone.setText("Done");
    jButtonDone.addActionListener(new ActionListener()
      {
      public void actionPerformed(ActionEvent e)
        { jButtonDone_actionPerformed(e); }
      });
    jRadioINFO.setText("INFO");
    jRadioINFO.addActionListener(new ActionListener()
      {
      public void actionPerformed(ActionEvent e)
        { jRadioINFO_actionPerformed(e); }
      });
    jRadioWARNING.setToolTipText("Log warnings such as file-not-found");
    jRadioWARNING.setText("WARNING");
    jRadioWARNING.addActionListener(new ActionListener()
      {
      public void actionPerformed(ActionEvent e)
        { jRadioWARNING_actionPerformed(e); }
      });
    jRadioSEVERE.setToolTipText("Log only exceptions");
    jRadioSEVERE.setText("SEVERE");
    jRadioSEVERE.addActionListener(new ActionListener()
      {
      public void actionPerformed(ActionEvent e)
        { jRadioSEVERE_actionPerformed(e); }
      });
    jRadioOFF.setToolTipText("Turn all logging off");
    jRadioOFF.setSelected(true);
    jRadioOFF.setText("OFF");
    jRadioOFF.addActionListener(new ActionListener()
      {
      public void actionPerformed(ActionEvent e)
        { jRadioOFF_actionPerformed(e); }
      });
    jPanelWest.setFont(new java.awt.Font("Tahoma", Font.BOLD, 11));
    jPanelWest.setBorder(titledBorder1);
    jPanelWest.setLayout(gridBagLayout2);
    this.getContentPane().setBackground(SystemColor.control);
    this.setFont(new java.awt.Font("Dialog", Font.BOLD, 12));
    this.getContentPane().setLayout(borderLayout1);
    jPaneCenter.setLayout(gridBagLayout1);
    jRadioCONFIG.setToolTipText("Used to log general flow of the prgarm");
    jRadioCONFIG.setText("CONFIG");
    jRadioCONFIG.addActionListener(new ActionListener()
      {
      public void actionPerformed(ActionEvent e)
        { jRadioCONFIG_actionPerformed(e); }
      });
    jRadioFINE.setToolTipText("Log some of the actions within methods");
    jRadioFINE.setText("FINE");
    jRadioFINE.addActionListener(new ActionListener()
      {
      public void actionPerformed(ActionEvent e)
        { jRadioFINE_actionPerformed(e); }
      });
    jRadioFINER.setText("FINER");
    jRadioFINER.addActionListener(new ActionListener()
      {
      public void actionPerformed(ActionEvent e)
        { jRadioFINER_actionPerformed(e); }
      });
    jRadioFINEST.setToolTipText(
        "Log nitty-gritty details of what goes on in the methods");
    jRadioFINEST.setText("FINEST");
    jRadioFINEST.addActionListener(new ActionListener()
      {
      public void actionPerformed(ActionEvent e)
        { jRadioFINEST_actionPerformed(e); }
      });
    jRadioALL.setToolTipText("Log everything");
    jRadioALL.setText("ALL");
    jRadioALL.addActionListener(new ActionListener()
      {
      public void actionPerformed(ActionEvent e)
        { jRadioALL_actionPerformed(e); }
      });
    titledBorder1.setTitle("Log Levels");
    titledBorder1.setTitleFont(new java.awt.Font("Tahoma", Font.BOLD, 11));
    jButtonReadLogFile.setText("Read the log file");
    jButtonReadLogFile.addActionListener(new ActionListener()
      {
      public void actionPerformed(ActionEvent e)
        { jButtonReadLogFile_actionPerformed(e); }
      });
    jButtonAddEnvironmentVariables.setToolTipText(
        "Clicking this button will add a number of Java environent variables " +
        "to the log file");
    jButtonAddEnvironmentVariables.setText("Add environment variables");
    jButtonAddEnvironmentVariables.addActionListener(new ActionListener()
      {
      public void actionPerformed(ActionEvent e)
        { jButtonAddEnvironmentVariables_actionPerformed(e); }
      });
    jLabelInfoSpacer.setText("    ");
    jButtonHelp.setText("Help");
    jButtonHelp.addActionListener(new ActionListener()
      {
      public void actionPerformed(ActionEvent e)
        { jButtonHelp_actionPerformed(e); }
      });
    jLabelSpacer2.setText("  ");
    jLabel2.setFont(new java.awt.Font("Tahoma", Font.PLAIN, 8));
    jLabel2.setToolTipText("");
    jLabel2.setText(" ");
    jPaneCenter.setPreferredSize(new Dimension(325, 275));
    jLabel3.setText(" ");
    jLabel1.setToolTipText("");
    jLabel1.setText(" ");
    buttonGroup1.add(jRadioOFF);
    buttonGroup1.add(jRadioSEVERE);
    buttonGroup1.add(jRadioALL);
    buttonGroup1.add(jRadioFINEST);
    buttonGroup1.add(jRadioFINER);
    buttonGroup1.add(jRadioFINE);
    buttonGroup1.add(jRadioCONFIG);
    buttonGroup1.add(jRadioINFO);
    buttonGroup1.add(jRadioWARNING);
    this.getContentPane().add(jPanelWest, java.awt.BorderLayout.WEST);
    this.getContentPane().add(jPaneCenter, java.awt.BorderLayout.CENTER);
    jPanelWest.add(jRadioOFF, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
        , GridBagConstraints.CENTER, GridBagConstraints.NONE,
        new Insets(5, 5, 0, 5), 30, 0));
    jPanelWest.add(jRadioSEVERE, new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0
        , GridBagConstraints.CENTER, GridBagConstraints.NONE,
        new Insets(0, 5, 0, 5), 12, 0));
    jPanelWest.add(jRadioWARNING, new GridBagConstraints(0, 2, 1, 1, 0.0, 0.0
        , GridBagConstraints.CENTER, GridBagConstraints.NONE,
        new Insets(0, 5, 0, 5), 0, 0));
    jPanelWest.add(jRadioINFO, new GridBagConstraints(0, 3, 1, 1, 0.0, 0.0
        , GridBagConstraints.CENTER, GridBagConstraints.NONE,
        new Insets(0, 5, 0, 5), 24, 0));
    jPanelWest.add(jRadioCONFIG, new GridBagConstraints(0, 4, 1, 1, 0.0, 0.0
        , GridBagConstraints.CENTER, GridBagConstraints.NONE,
        new Insets(0, 5, 0, 5), 10, 0));
    jPanelWest.add(jRadioFINE, new GridBagConstraints(0, 5, 1, 1, 0.0, 0.0
        , GridBagConstraints.CENTER, GridBagConstraints.NONE,
        new Insets(0, 5, 0, 5), 26, 0));
    jPanelWest.add(jRadioFINER, new GridBagConstraints(0, 6, 1, 1, 0.0, 0.0
        , GridBagConstraints.CENTER, GridBagConstraints.NONE,
        new Insets(0, 5, 0, 5), 20, 0));
    jPanelWest.add(jRadioFINEST, new GridBagConstraints(0, 7, 1, 1, 0.0, 0.0
        , GridBagConstraints.CENTER, GridBagConstraints.NONE,
        new Insets(0, 5, 0, 5), 14, 0));
    jPanelWest.add(jRadioALL, new GridBagConstraints(0, 8, 1, 1, 0.0, 0.0
        , GridBagConstraints.CENTER, GridBagConstraints.NONE,
        new Insets(0, 5, 6, 5), 32, 0));
    jPaneCenter.add(jLabel3, new GridBagConstraints(0, 1, 1, 1, 0.0, 0.0
        , GridBagConstraints.WEST, GridBagConstraints.NONE,
        new Insets(0, 5, 0, 5), 314, 0));
    jPaneCenter.add(jLabelPathAndName,
                    new GridBagConstraints(0, 2, 1, 1, 0.0, 0.0
        , GridBagConstraints.WEST, GridBagConstraints.NONE,
        new Insets(0, 5, 0, 5), 188, 0));
    jPaneCenter.add(jLabelPathName, new GridBagConstraints(0, 3, 1, 1, 0.0, 0.0
        , GridBagConstraints.WEST, GridBagConstraints.NONE,
        new Insets(0, 5, 0, 5), 273, 0));
    jPaneCenter.add(jLabelSpacer2, new GridBagConstraints(0, 4, 1, 1, 0.0, 0.0
        , GridBagConstraints.WEST, GridBagConstraints.NONE,
        new Insets(0, 5, 0, 5), 311, 0));
    jPaneCenter.add(jLabelInfoSpacer,
                    new GridBagConstraints(0, 8, 1, 1, 0.0, 0.0
        , GridBagConstraints.WEST, GridBagConstraints.NONE,
        new Insets(0, 5, 0, 5), 301, 0));
    jPaneCenter.add(jLabel2, new GridBagConstraints(0, 10, 1, 1, 0.0, 0.0
        , GridBagConstraints.WEST, GridBagConstraints.NONE,
        new Insets(0, 5, 0, 5), 317, 0));
    jPaneCenter.add(jLabel1, new GridBagConstraints(0, 6, 1, 1, 0.0, 0.0
        , GridBagConstraints.CENTER, GridBagConstraints.NONE,
        new Insets(0, 0, 0, 0), 0, 0));
    jPaneCenter.add(jButtonDone, new GridBagConstraints(0, 11, 1, 1, 0.0, 0.0
        , GridBagConstraints.CENTER, GridBagConstraints.NONE,
        new Insets(0, 5, 7, 5), 13, 0));
    jPaneCenter.add(jButtonHelp, new GridBagConstraints(0, 9, 1, 1, 0.0, 0.0
        , GridBagConstraints.CENTER, GridBagConstraints.NONE,
        new Insets(0, 5, 0, 5), 17, 0));
    jPaneCenter.add(jButtonReadLogFile,
                    new GridBagConstraints(0, 7, 1, 1, 0.0, 0.0
        , GridBagConstraints.CENTER, GridBagConstraints.NONE,
        new Insets(0, 5, 0, 5), 15, 0));
    jPaneCenter.add(jButtonAddEnvironmentVariables,
                    new GridBagConstraints(0, 5, 1, 1, 0.0, 0.0
        , GridBagConstraints.CENTER, GridBagConstraints.NONE,
        new Insets(0, 5, 0, 5), 1, 0));
    jPaneCenter.add(jLabelTop, new GridBagConstraints(0, 0, 1, 1, 0.0, 0.0
        , GridBagConstraints.WEST, GridBagConstraints.NONE,
        new Insets(5, 5, 0, 5), 58, 0)); // End of JBuilder GUI generated code

    logFilePath = Logger.getLogFilePath();  // Save file path for future use
    logFileName = Logger.getLogFileName();  // Save file name for future use
    logHelpFilePath = Logger.getLogItHelpPath();
    logHelpFileName = Logger.getlogItHelpFileName();
    jLabelPathName.setText(logFilePath + logFileName);
    this.pack();

   // Position the dialog
   if (parent == null)
     { // If there is no parent then position the dialog at the upper left
     this.setLocation(20, 20);
     }
   else
     { // Else position the dialog over the center of the parent
     Dimension dlgSize = this.getPreferredSize();
     Dimension frmSize = parent.getSize();
     Point loc = parent.getLocation();
     this.setLocation( (frmSize.width - dlgSize.width) / 2 + loc.x,
                      (frmSize.height - dlgSize.height) / 2 + loc.y);
     }
    setVisible(true);

    Logger.writeLog(Logger.CONFIG, "LogIt exiting jbInit");

  } // END  //END jbInit()


//##############################################################################
  private void jButtonDone_actionPerformed(ActionEvent e)
    { // User pressed the DONE button
    Logger.writeLog(Logger.CONFIG, "LogIt jButtonDone_actionPerformed");
    Logger.setLogLevel(newLogLevel);
    dispose();
    }

//##############################################################################
  private static void jButtonAddEnvironmentVariables_actionPerformed(ActionEvent e)
    {
    // Write selected environment variables to log file
    System.out.println("############# JAVA Environment Variables ############");

    environmentVariable = System.getProperty("java.version");
    System.out.println("                Java.version  = " + environmentVariable);

    environmentVariable = System.getProperty("java.vendor");
    System.out.println("                  Java.vendor = " + environmentVariable);

    environmentVariable = System.getProperty("java.home");
    System.out.println("                    Java.home = " + environmentVariable);

    environmentVariable = System.getProperty("java.vm.name");
    System.out.println("                 Java.vm.name = " + environmentVariable);

    environmentVariable = System.getProperty("java.specification.version");
    System.out.println("Java.vm.specification.version = " + environmentVariable);

    environmentVariable = System.getProperty("java.class.path");
    System.out.println("              Java.class.path = " + environmentVariable);

    environmentVariable = System.getProperty("java.library.path");
    System.out.println("            Java.library.path = " + environmentVariable);

    environmentVariable = System.getProperty("java.io.tmpdir");
    System.out.println("               Java.io.tmpdir = " + environmentVariable);

    environmentVariable = System.getProperty("java.compiler");
    System.out.println("                Java.compiler = " + environmentVariable);

    environmentVariable = System.getProperty("os.name");
    System.out.println("                      os.name = " + environmentVariable);

    environmentVariable = System.getProperty("os.arch");
    System.out.println("                      os.arch = " + environmentVariable);

    environmentVariable = System.getProperty("os.version");
    System.out.println("                   os.version = " + environmentVariable);

    environmentVariable = System.getProperty("file.separator");
    System.out.println("               file.separator = " + environmentVariable);

    environmentVariable = System.getProperty("path.separator");
    System.out.println("               path.separator = " + environmentVariable);

    environmentVariable = System.getProperty("line.separator");
    System.out.println("               line.separator = " + environmentVariable);

    environmentVariable = System.getProperty("user.name");
    System.out.println("                    user.name = " + environmentVariable);

    environmentVariable = System.getProperty("user.home");
    System.out.println("                    user.home = " + environmentVariable);

    environmentVariable = System.getProperty("user.dir");
    System.out.println("                     user.dir = " + environmentVariable);

    System.out.println("########### End JAVA Environment Variables ###########");
    }

//##############################################################################
  // The following simply capture which was the last log level radio button
  // to be clicked.
  private static void jRadioOFF_actionPerformed(ActionEvent e)
    {
    newLogLevel = Logger.OFF;
    Logger.writeLog(Logger.FINE, "LogIt jRadioOFF_actionPerformed");
    }

  private static void jRadioSEVERE_actionPerformed(ActionEvent e)
    {
    newLogLevel = Logger.SEVERE;
    Logger.writeLog(Logger.FINE, "LogIt jRadioSEVERE_actionPerformed");
    }

  private static void jRadioWARNING_actionPerformed(ActionEvent e)
    {
    newLogLevel = Logger.WARNING;
    Logger.writeLog(Logger.FINE, "LogIt jRadioWARNING_actionPerformed");
    }

  private static void jRadioINFO_actionPerformed(ActionEvent e)
    {
    newLogLevel = Logger.INFO;
    Logger.writeLog(Logger.FINE, "LogIt jRadioINFO_actionPerformed");
    }

  private static void jRadioCONFIG_actionPerformed(ActionEvent e)
    {
    newLogLevel = Logger.CONFIG;
    Logger.writeLog(Logger.FINE, "LogIt jRadioCONFIG_actionPerformed");
    }

  private static void jRadioFINE_actionPerformed(ActionEvent e)
    {
    newLogLevel = Logger.FINE;
    Logger.writeLog(Logger.FINE, "LogIt jRadioFINE_actionPerformed");
    }

  private static void jRadioFINER_actionPerformed(ActionEvent e)
    {
    newLogLevel = Logger.FINER;
    Logger.writeLog(Logger.FINE, "LogIt jRadioFINER_actionPerformed");
    }

  private static void jRadioFINEST_actionPerformed(ActionEvent e)
    {
    newLogLevel = Logger.FINEST;
    Logger.writeLog(Logger.FINE, "LogIt jRadioFINEST_actionPerformed");
    }

  private static void jRadioALL_actionPerformed(ActionEvent e)
    {
    newLogLevel = Logger.ALL;
    Logger.writeLog(Logger.FINE, "LogIt jRadioALL_actionPerformed");
    }

//##############################################################################
  private  void jButtonReadLogFile_actionPerformed(ActionEvent e)
    {
    Logger.writeLog(Logger.CONFIG, "LogIt jButtonReadLogFile_actionPerformed");
    TextViewer dlg = new TextViewer(logFilePath, logFileName);
    }

//##############################################################################
  // Show the help file for this dialog
  private void jButtonHelp_actionPerformed(ActionEvent e)
    {
    Logger.writeLog(Logger.CONFIG, "LogIt jButtonHelp_actionPerformed");
    HTMLviewer dlg = new HTMLviewer(logHelpFilePath,logHelpFileName);
    }

//##############################################################################
  /**
   * Returns the name of the class.
   *
   * @return The class name, log file path+name, log level and log help file
   * path+name.  For example:
   * <p>
   * LogIt LogFile=D:\A JOptionPanel\Log.txt Log Level=1
   *  HelpFile=D:\A JOptionPanel\LogItHelp.htm
   */
  public String toString()
    { return "LogIt LogFile="+Logger.getLogFilePath()
                              +Logger.getLogFileName()
                              + " Log Level="
                              + Logger.getLogLevel()
                              + " HelpFile="
                              + Logger.getLogItHelpPath()
                              + Logger.getlogItHelpFileName();
    }

} // END LogIt
